#!/bin/sh

if [ -z "$SAPPHIRE" ]
then
	if [ -d /usr/sapphire1.0 ]
	then
		echo "SAPPHIRE environment variable not set. Using /usr/sapphire1.0"
		SAPPHIRE=/usr/sapphire1.0
		export SAPPHIRE
	else
		echo "SAPPHIRE environment variable not set."
		echo "Tried /usr/sapphire1.0, but failed. Exiting"
		exit 1
	fi
fi

if [ ! -d $SAPPHIRE ]
then
	echo "Invalid SAPPHIRE environent variable. Exiting"
	exit 1
fi

PATH=$SAPPHIRE/bin:$PATH
SOMETHING_STARTED=""
export PATH SAPPHIRE


if [ -x $SAPPHIRE/bin/dborbd.syb ]
then
	if [ -z "$SYBASE" ]
	then
	  echo "Not starting SYBASE orb because SYBASE environment variable not set"
	else
		$SAPPHIRE/bin/dborbd.syb $* &
		echo "Starting Sybase Orb..."
		SOMETHING_STARTED="y"
	fi
fi

if [ -x $SAPPHIRE/bin/dborbd.ora ]
then
	if [ -z "$ORACLE_HOME" -a -z "$ORACLE_SID" ]
	then
		echo "Not starting ORACLE orb because one of the environment variables,"
		echo "        ORACLE_HOME or ORACLE_SID, is not set"
	else
		$SAPPHIRE/bin/dborbd.ora $* &
		echo "Starting Oracle Orb..."
		SOMETHING_STARTED="y"
	fi
fi

if [ -x $SAPPHIRE/bin/dborbd.inf ]
then
	if [ -z "$INFORMIXDIR" ]
	then
	  echo "Not starting INFORMIX orb because INFORMIXDIR environment variable not set"
	else
		$SAPPHIRE/bin/dborbd.inf $* &
		echo "Starting Informix Orb..."
		SOMETHING_STARTED="y"
	fi
fi

if [ ! -x $SAPPHIRE/bin/dborbd.syb ]
then
	if [ ! -x $SAPPHIRE/bin/dborbd.ora ]
	then
		if [ ! -x $SAPPHIRE/bin/dborbd.inf ]
		then
			echo "No Orb executables found. "
			echo "You must build the orb executables before using."
			echo "See the Installation instructions for details. "
	 		echo "Exiting..."
			exit 1
		fi
	fi
fi

if [ -z "$SOMETHING_STARTED" ]
then
	echo "No Orbs started"
	echo "Exiting..."
	exit 1
fi

exit 0
