#!/bin/sh 
#
###############################################################################
#                                                                             #
#                Copyright (c) 1995 Bluestone                                 #
#                                                                             #
#      All rights reserved.  This notice is  intended  as  a  precaution      #
#      against  inadvertent publication, and shall not be deemed to con-      #
#      stitute an acknowledgment that publication has  occurred  nor  to      #
#      imply  any  waiver  of confidentiality.  The year included in the      #
#      notice is the year of the creation of the work.                        #
#                                                                             #
#                                                                             #
###############################################################################


# Things that may change when porting

CAT="cat"
DATE="date"
ECHO="echo"
ECHON="echo -n"
GREP="grep"
RCP="rcp"
RM="rm"
SED="sed"
READ="read"
MKDIR="mkdir"
CHMOD="chmod"
TOUCH="touch"
WHOAMI="whoami"
HOSTNAME="hostname"
BASENAME="basename"

COPY="cp"

# Things likely to change for updates

PRODUCT="Sapphire/Web Beta"
SERVER=$1
OWNER=$2
VENDOR=$3
tutName=$4

TUTSUBDIR="$SAPPHIRE/tutorials/$tutName"

# Subroutines

usage()
{
   $ECHO
   $ECHO "Usage: $0 <server name> <owner> <S|O|I> <tutorial name>"
   $ECHO
   exit 1
}

check_status()
{
  if [ $? != 0 ]
   then
      $ECHO
      $ECHO "$1"
      $ECHO
      $ECHO "Please correct the problem and try again..."
      $ECHO
      $ECHO "Exiting..."
      $ECHO
      exit 1
   fi
}
# Check for the SAPPHIRE env variable

if [ "$SAPPHIRE" = "" ]
then
   $ECHO
   $ECHO "The SAPPHIRE environment variable is not set.  Please set this"
   $ECHO "environment variable to the directory where you installed"
   $ECHO "$PRODUCT before continuing."
   $ECHO
   $ECHO "Exiting..."
   $ECHO
   exit 1
fi

if [ ! -f "$SAPPHIRE/bin/saweb" ]
then
   $ECHO
   $ECHO "$SAPPHIRE is not a valid $PRODUCT directory."
   $ECHO "Please reinstall $PRODUCT before proceeding."
   $ECHO
   $ECHO "Exiting..."
   $ECHO
   exit 1
fi
# Check args

if [ "$#" != "4" ]
then
   usage
fi


# Copy C files to Project Directory

$ECHO
$ECHO "Copying Module (C) files"

TMPHTML="/tmp/html_copy_tmp.$$"

for i in ${TUTSUBDIR}/src/*.c
do
   b=`$BASENAME $i`
   f="$i"
   t="$TUTSUBDIR/html/${b}"
   if [ "$VENDOR" = "O" ]
	then
	   $SED -e "s%CEZANNE%ORACLE%" \
    	    -e "s%pubs2%$SERVER%" \
    	    -e "s%SGESYBASE%SGEORACLE%" \
    	    -e "s%PROCESSBRSREQUEST_DSQL%PROCESSBRSREQUEST_OSQL%" \
    	    -e "s%dbo.%${OWNER}.%" \
      	$f > $TMPHTML
	elif [ "$VENDOR" = "S" ]
	then
	   $SED -e "s%CEZANNE%$SERVER%" \
      	$f > $TMPHTML
	elif [ "$VENDOR" = "I" ]
	then
	   $SED -e "s%CEZANNE%$SERVER%" \
    	    -e "s%SGESYBASE%SGEINFORMIX%" \
    	    -e "s%PROCESSBRSREQUEST_DSQL%PROCESSBRSREQUEST_ISQL%" \
    	    -e "s%dbo.%${OWNER}.%" \
      	$f > $TMPHTML
	else	
		$ECHO
		$ECHO "Fatal error in script, Unknown VENDOR $VENDOR"
		$ECHO
		$ECHO "Exiting"
		exit 1
	fi
	
   $COPY $TMPHTML $t
   check_status "Can't copy $f to $t"

   $RM $TMPHTML

   $ECHO "   $i"
done



