#!/bin/sh
#
# 95-08-13 WJE; Created
#             ; Loads and properly formats DSQL object files given four args
#

TOUCH="touch"
ECHO="echo"
SED="sed"
RM="rm"

# Subroutines

usage()
{
   $ECHO
   $ECHO "Usage: $0 <server name> <owner> <S|O|I> <destination dir>"
   $ECHO
   exit 1
}

check_status()
{
  if [ $? != 0 ]
   then
      $ECHO
      $ECHO "$1"
      $ECHO
      $ECHO "Please correct the problem and try again..."
      $ECHO
      $ECHO "Exiting..."
      $ECHO
      exit 1
   fi
}

# Check for the SAPPHIRE env variable

if [ "$SAPPHIRE" = "" ]
then
   $ECHO
   $ECHO "The SAPPHIRE environment variable is not set.  Please set this"
   $ECHO "environment variable to the directory where you installed"
   $ECHO "$PRODUCT before continuing."
   $ECHO
   $ECHO "Exiting..."
   $ECHO
   exit 1
fi

if [ ! -f "$SAPPHIRE/bin/saweb" ]
then
   $ECHO
   $ECHO "$SAPPHIRE is not a valid $PRODUCT directory."
   $ECHO "Please reinstall $PRODUCT before proceeding."
   $ECHO
   $ECHO "Exiting..."
   $ECHO
   exit 1
fi

# Check args

if [ "$#" != "4" ]
then
   usage
fi

case $3 in
   S|I)
      A1="$1"
      A2="pubs2"
      ;;
   O)
      A1="ORACLE"
      A2="$1"
esac

A3="$3"
A4="$4"
A5="$2"

# See if arg 4 is a directory

if [ ! -d "$4" ]
then
   $ECHO
   $ECHO "$4 is not a directory."
   usage
fi

TF="$A4/generic_load.$$"

$TOUCH "$TF" 2> /dev/null
check_status "Can't create files in $4"

$RM "$TF"

cd $SAPPHIRE/tutorials/dsql

for i in SERVER,DB*
do
   # First, create the destination filename

   dstf=`echo "$i" | \
      $SED -e "s%SERVER,%$A1,%" \
           -e "s%,DB,%,$A2,%"   \
           -e "s%,C%,$A3%" `

   dstp="$A4/$dstf"

   # Now, create dst file with dbo sed already done

   $SED -e "s%dbo\.%$A5.%g" < $i > $dstp

   $ECHO "$dstf Created"
done





