#!/bin/sh
######################################################################
# saweb
#
# Shell script to set up environment and run Sapphire/Web
######################################################################

if [ "`echo $1 | cut -c1-2`" = "-d" ]; then
  DISPLAY=$2
  export DISPLAY
fi

INSTALLDIR=BLUESTONE_SAPPHIRE_PATH

if [ -z "$SAPPHIRE" ]
then
	if [ -d $INSTALLDIR ]
	then
		echo "SAPPHIRE environment variable not set. Using $INSTALLDIR"
		SAPPHIRE=$INSTALLDIR
		export SAPPHIRE
	else
		echo "SAPPHIRE environment variable not set."
		echo "Tried $INSTALLDIR, but failed. Exiting"
		exit 1
	fi
fi

if [ ! -d $SAPPHIRE ]
then
	echo "Invalid SAPPHIRE environent variable. Exiting"
	exit 1
fi

PATH=$PATH:$SAPPHIRE/bin

export PATH

if [ ! -x $SAPPHIRE/bin/saweb.real ]
then
	echo "Invalid SAPPHIRE environent variable. Exiting"
	exit 1
fi

if [ -d $SAPPHIRE/msg/C ]
then
	NLSPATH="%N:/$SAPPHIRE/msg/C/%N"
	export NLSPATH
else
	echo "NLSPATH directory $SAPPHIRE/msg/C does not exist. Exiting."
	exit 1
fi

######################################################################
## Check for /usr/lib/X11/XKeysymDB
## If file is missing, and XKEYSYMDB is set, use it.
## Otherwise, set XKEYSYMDB to point into this distribution.
######################################################################
if [ ! -r /usr/lib/X11/XKeysymDB ]
then
   if [ -z "$XKEYSYMDB" ]
   then
      echo "XKEYSYMDB environment variable is not set."
      XKEYSYMDB=$SAPPHIRE/nls/XKeysymDB
      export XKEYSYMDB
      echo "Using $XKEYSYMDB."
   elif [ ! -r "$XKEYSYMDB" ]
   then
      echo ""
      echo "Invalid XKEYSYMDB environment variable."
      echo "Exiting."
      exit 1
   fi
fi

######################################################################
## Check for /usr/lib/X11/nls
## If directory is missing, and XNLSPATH is set, use it.
## Otherwise, set XNLSPATH to point into this distribution.
######################################################################
if [ ! -d /usr/lib/X11/nls ]
then
   if [ -z "$XNLSPATH" ]
   then
      echo "XNLSPATH environment variable is not set."
      XNLSPATH=$SAPPHIRE/nls
      export XNLSPATH
      echo "Using $XNLSPATH."
   elif [ ! -d "$XNLSPATH" ]
   then
      echo ""
      echo "Invalid XNLSPATH environment variable."
      echo "Exiting."
      exit 1
   fi
fi

$SAPPHIRE/bin/saweb.real $*
