{ DATABASE pubs2  delimiter | }

grant dba to "informix";

{ TABLE "informix".authors row size = 167 number of columns = 9 index size = 118 
              }
{ unload file name = authors100.unl number of rows = 23 }

create table "informix".authors 
  (
    au_id char(11),
    au_lname varchar(40),
    au_fname varchar(20),
    phone char(12),
    address varchar(40),
    city varchar(20),
    state char(2),
    country varchar(12),
    postalcode char(10),
    primary key (au_id) constraint "informix".u100_1
  );
grant all on "informix".authors to "public";

create unique index "informix".aunmind on "informix".authors (au_lname,au_fname);

{ TABLE "informix".author_url row size = 521 number of columns = 3 index size = 118 
              }
{ unload file name = author_url113.unl number of rows = 23 }

create table "informix".author_url 
  (
    au_id char(11),
    au_pic_url varchar(255),
    au_snd_url varchar(255),
    primary key (au_id) constraint "informix".u113_1
  );
grant all on "informix".author_url to "public";

{ TABLE "informix".publishers row size = 66 number of columns = 4 index size = 12 
              }
{ unload file name = publish101.unl number of rows = 3 }

create table "informix".publishers 
  (
    pub_id char(4),
    pub_name varchar(40),
    city varchar(20),
    state char(2),
    primary key (pub_id) constraint "informix".u101_2
  );
grant all on "informix".publishers to "public";

{ TABLE "informix".titles row size = 332 number of columns = 10 index size = 141 
              }
{ unload file name = titles_106.unl number of rows = 17 }

create table "informix".titles 
  (
    title_id char(6),
    title varchar(80),
    type char(12),
    pub_id char(4),
    price money(16,2),
    advance money(16,2),
    total_sales integer,
    notes varchar(200),
    pubdate date,
    contract integer,
    primary key (title_id) constraint "informix".u106_7
  );
grant all on "informix".titles to "public";

create unique index "informix".titleind on "informix".titles (title);
{ TABLE "informix".stores row size = 140 number of columns = 8 index size = 12 }
{ unload file name = stores_107.unl number of rows = 7 }

create table "informix".stores 
  (
    stor_id char(4),
    stor_name varchar(40),
    stor_address varchar(40),
    city varchar(20),
    state char(2),
    country varchar(12),
    postalcode char(10),
    payterms varchar(12),
    primary key (stor_id) constraint "informix".u107_8
  );
grant all on "informix".stores to "public";

{ TABLE "informix".discounts row size = 60 number of columns = 5 index size = 66 
              }
{ unload file name = discoun108.unl number of rows = 4 }

create table "informix".discounts 
  (
    discounttype varchar(40),
    stor_id char(4),
    lowqty smallint,
    highqty smallint,
    discount float,
    primary key (discounttype) constraint "informix".u108_9
  );
grant all on "informix".discounts to "public";

{ TABLE "informix".roysched row size = 18 number of columns = 4 index size = 0 }
{ unload file name = roysche109.unl number of rows = 87 }

create table "informix".roysched 
  (
    title_id char(6),
    lorange integer,
    hirange integer,
    royalty integer
  );
grant all on "informix".roysched to "public";

{ TABLE "informix".sales row size = 28 number of columns = 3 index size = 0 }
{ unload file name = sales__110.unl number of rows = 30 }

create table "informix".sales 
  (
    stor_id char(4),
    ord_num varchar(20),
    adate date
  );
grant all on "informix".sales to "public";

{ TABLE "informix".salesdetail row size = 42 number of columns = 5 index size = 0 
              }
{ unload file name = salesde111.unl number of rows = 116 }

create table "informix".salesdetail 
  (
    stor_id char(4),
    ord_num varchar(20),
    title_id char(6),
    qty smallint,
    discount float
  );
grant all on "informix".salesdetail to "public";

{ TABLE "informix".titleauthor row size = 25 number of columns = 4 index size = 0 
              }
{ unload file name = titleau112.unl number of rows = 25 }

create table "informix".titleauthor 
  (
    au_id char(11),
    title_id char(6),
    au_ord smallint,
    royaltyper integer
  );
grant all on "informix".titleauthor to "public";

create view "informix".titleview (title,au_ord,au_lname,price,total_sales,pub_id) as 
  select x1.title ,x2.au_ord ,x0.au_lname ,x1.price ,x1.total_sales 
    ,x1.pub_id from "informix".authors x0 ,"informix".titles x1 
    ,"informix".titleauthor x2 where ((x0.au_id = x2.au_id ) AND 
    (x1.title_id = x2.title_id ) ) ;                


CREATE PROCEDURE "informix".d12_insert(
	aid CHAR(4), 
	aname VARCHAR(40), 
	acity VARCHAR(20), 
	astate CHAR(2)
)
INSERT INTO
	publishers
VALUES (
	aid,
	aname,
	acity,
	astate
	);

END PROCEDURE;

CREATE PROCEDURE "informix".d12_delete(
	aid CHAR(4)
)
DELETE FROM
	publishers
WHERE
	pub_id = aid;

END PROCEDURE;

CREATE PROCEDURE "informix".d12_update(
	aid CHAR(4), 
	aname VARCHAR(40), 
	acity VARCHAR(20), 
	astate CHAR(2)
)
UPDATE
	publishers
SET
	pub_name = aname,
	city = acity,
	state = astate
WHERE
	pub_id = aid;

END PROCEDURE;

CREATE PROCEDURE "informix".m_authors_info()
RETURNING CHAR(11), CHAR(40), CHAR(20), 
	CHAR(12), CHAR(40), CHAR(20),
	CHAR(2), CHAR(12), CHAR(10);

DEFINE vau_id CHAR(11);
DEFINE vau_lname, vaddress CHAR(40);
DEFINE vau_fname, vcity CHAR(20);
DEFINE vphone, vcountry CHAR(12);
DEFINE vstate CHAR(2);
DEFINE vpostalcode CHAR(10);

FOREACH
	SELECT
		au_id, au_lname, au_fname,
		phone, address, city,
		state, country, postalcode
	INTO
		vau_id, vau_lname, vau_fname,
		vphone, vaddress, vcity,
		vstate, vcountry, vpostalcode
	FROM
		authors
	RETURN
		vau_id, vau_lname, vau_fname,
		vphone, vaddress, vcity,
		vstate, vcountry, vpostalcode
	WITH RESUME;

END FOREACH;

END PROCEDURE;

CREATE PROCEDURE "informix".m_insert_author(
aid char(11),
alname varchar(40),
afname varchar(20),
aphone char(12),
aaddr varchar(40),
acity varchar(20),
astate char(2),
acountry varchar(12),
apostal char(10)
)

INSERT INTO
	authors
VALUES(
	aid,
	alname,
	afname,
	aphone,
	aaddr,
	acity,
	astate,
	acountry,
	apostal
);

END PROCEDURE;

CREATE PROCEDURE "informix".m_update_author(
	aid CHAR(11),
	alname varchar(40),
	afname varchar(20),
	aphone char(12),
	aaddr varchar(40),
	acity varchar(20),
	astate char(2),
	acountry varchar(12),
	apostal char(10)
)

UPDATE
	authors
SET
	au_lname = alname,
	au_fname = afname,
	phone = aphone,
	address = aaddr,
	city = acity,
	state = astate,
	country = acountry,
	postalcode = apostal
WHERE 
	au_id = aid;

END PROCEDURE;

CREATE PROCEDURE "informix".m_delete_author(aid CHAR(11))

DELETE FROM 
	authors
WHERE 
	au_id = aid;

END PROCEDURE;

CREATE PROCEDURE "informix".d10_titles(atitle varchar(80))
RETURNING VARCHAR(80);

DEFINE vtitle VARCHAR(80);

FOREACH
	SELECT title
		INTO vtitle
		FROM titles
		WHERE title like atitle || '%'
	RETURN vtitle 
	WITH RESUME;
END FOREACH;

END PROCEDURE;

CREATE PROCEDURE "informix".d10_storelist()
RETURNING varchar(40);

DEFINE vname varchar(40);

FOREACH
	SELECT stor_name
		INTO vname
		FROM stores
	RETURN vname
	WITH RESUME;
END FOREACH;


END PROCEDURE;

CREATE PROCEDURE "informix".d10_storesales(atitle varchar(80), astore varchar(40))
RETURNING 	CHAR(8), CHAR(20), CHAR(2), 
		CHAR(8), INT, CHAR(2),
		CHAR(9), FLOAT;
DEFINE vs1, vs2 CHAR(8);
DEFINE vs3, vs4 CHAR(2);
DEFINE vs5 CHAR(9);
DEFINE vord_num CHAR(20);
DEFINE vqty INT;
DEFINE vdiscount FLOAT;

FOREACH
	SELECT
		"Order #:", d.ord_num, "--",
		"Quanity:", d.qty, "--",
		"Discount:", d.discount
	INTO
		vs1, vord_num, vs3,
		vs2, vqty, vs4,
		vs5, vdiscount
	FROM
		titles t, stores s, salesdetail d
	WHERE
		t.title = atitle AND
		t.title_id = d.title_id AND
		s.stor_id = d.stor_id AND
		s.stor_name = astore
	RETURN
		vs1, vord_num, vs3,
		vs2, vqty, vs4,
		vs5, vdiscount
	WITH RESUME;

END FOREACH;

END PROCEDURE;

CREATE PROCEDURE "informix".d10_publisher(atitle varchar(80))
RETURNING CHAR(40), CHAR(4), CHAR(20), CHAR(2);

DEFINE vpub_name CHAR(40);
DEFINE vpub_id CHAR(4);
DEFINE vcity CHAR(20);
DEFINE vstate CHAR(2);

FOREACH
	SELECT
		p.pub_name,
		p.pub_id,
		p.city,
		p.state
	INTO
		vpub_name,
		vpub_id,
		vcity,
		vstate
	FROM
		publishers p, titles t
	WHERE
		t.pub_id = p.pub_id AND
		t.title = atitle
	RETURN
		vpub_name,
		vpub_id,
		vcity,
		vstate
	WITH RESUME;
END FOREACH;

END PROCEDURE;

CREATE PROCEDURE "informix".d10_author(atitle varchar(80))
RETURNING 
	CHAR(20), CHAR(40), CHAR(40), 
	CHAR(20), CHAR(2), CHAR(10), 
	CHAR(12), MONEY(16, 2), INT;

DEFINE vau_fname, vcity CHAR(20);
DEFINE vau_lname, vaddress CHAR(40);
DEFINE vstate CHAR(2);
DEFINE vpostalcode CHAR(10);
DEFINE vphone CHAR(12);
DEFINE vadvance MONEY(16, 2);
DEFINE vtotal_sales INT;

FOREACH
	SELECT
		a.au_fname,
		a.au_lname,
		a.address,
		a.city,
		a.state,
		a.postalcode,
		a.phone,
		t.advance,
		t.total_sales
	INTO
		vau_fname,
		vau_lname,
		vaddress,
		vcity,
		vstate,
		vpostalcode,
		vphone,
		vadvance,
		vtotal_sales
	FROM
		authors a,
		titles t,
		titleauthor ta
	WHERE
		a.au_id = ta.au_id AND
		t.title_id = ta.title_id AND
		t.title = atitle
	RETURN 
		vau_fname,
		vau_lname,
		vaddress,
		vcity,
		vstate,
		vpostalcode,
		vphone,
		vadvance,
		vtotal_sales
	WITH RESUME;
END FOREACH;

END PROCEDURE;

CREATE PROCEDURE "informix".d11_info()
RETURNING CHAR(40), CHAR(20), CHAR(12), CHAR(12);

DEFINE vau_lname CHAR(40);
DEFINE vau_fname CHAR(20);
DEFINE vphone, vcountry CHAR(12);

FOREACH
	SELECT
		au_lname, au_fname, phone, country
	INTO
		vau_lname, vau_fname, vphone, vcountry
	FROM
		authors
	ORDER BY
		au_lname, au_fname
	RETURN
		vau_lname, vau_fname, vphone, vcountry
	WITH RESUME;

END FOREACH;

END PROCEDURE;

CREATE PROCEDURE "informix".d12_find()
RETURNING CHAR(4), CHAR(40), CHAR(20), CHAR(2);

DEFINE vpub_id CHAR(4);
DEFINE vpub_name CHAR(40);
DEFINE vcity CHAR(20);
DEFINE vstate CHAR(2);

FOREACH
	SELECT 
		pub_id, pub_name, city, state
	INTO
		vpub_id, vpub_name, vcity, vstate
	FROM 
		publishers
	ORDER BY
		pub_name
	RETURN
		vpub_id, vpub_name, vcity, vstate
	WITH RESUME;

END FOREACH;

END PROCEDURE;



grant  execute on "informix".d12_insert to "public" as "informix";
grant  execute on "informix".d12_delete to "public" as "informix";
grant  execute on "informix".d12_update to "public" as "informix";
grant  execute on "informix".m_authors_info to "public" as "informix";
grant  execute on "informix".m_insert_author to "public" as "informix";
grant  execute on "informix".m_update_author to "public" as "informix";
grant  execute on "informix".m_delete_author to "public" as "informix";
grant  execute on "informix".d10_titles to "public" as "informix";
grant  execute on "informix".d10_storelist to "public" as "informix";
grant  execute on "informix".d10_storesales to "public" as "informix";
grant  execute on "informix".d10_publisher to "public" as "informix";
grant  execute on "informix".d10_author to "public" as "informix";
grant  execute on "informix".d11_info to "public" as "informix";
grant  execute on "informix".d12_find to "public" as "informix";

