/*==========================================================================*/
/*=                              tutprocs.sql                              =*/
/*==========================================================================*/


/*-------------------------------- SECTION I -------------------------------*/

/****************************************************************************/
/* This portion sets up the ability to perform all the functions in this    */
/* script                                                                   */
/****************************************************************************/

use pubs2
go
dump tran pubs2 with truncate_only
go

print "dropping Table author_url..."
go

if exists (select * from pubs2.dbo.sysobjects o, pubs2.dbo.sysusers u
	where 
		o.name = "author_url" and
		o.type = "U" and
		o.uid = u.uid and
		u.name = "dbo")
begin
	drop table pubs2.dbo.author_url
end
go

print "creating Table author_url..."
go

if exists (select * from master.dbo.sysdatabases
	where name = "pubs2")
begin
	create table author_url
	(au_id id not null,
	au_pic_url varchar(255) null,
	au_snd_url varchar(255) null)
end
go
grant select on author_url to public
go
execute sp_primarykey author_url, au_id
go
execute sp_foreignkey author_url, authors, au_id
go
create unique clustered index au_urlidind
on author_url (au_id)
go

dump tran pubs2 with truncate_only
go

if exists (select * from sysobjects
           where name = 'sp_configure' and sysstat & 7 = 4)
begin
    execute sp_configure 'update',1
end
reconfigure with override
go


/*----------------------------- SECTION II ----------------------------*/

/***********************************************************************/
/************** Drop Stored Procedures if they exist *******************/
/***********************************************************************/

if (exists (select * from sysobjects where name = 'D10_author'))
    drop proc D10_author
go

if (exists (select * from sysobjects where name = 'D10_publisher'))
    drop proc D10_publisher
go

if (exists (select * from sysobjects where name = 'D10_storelist'))
    drop proc D10_storelist
go

if (exists (select * from sysobjects where name = 'D10_storesales'))
    drop proc D10_storesales
go

if (exists (select * from sysobjects where name = 'D10_titles'))
    drop proc D10_titles
go

if (exists (select * from sysobjects where name = 'D11_info'))
    drop proc D11_info
go

if (exists (select * from sysobjects where name = 'D12_find'))
    drop proc D12_find
go

if (exists (select * from sysobjects where name = 'D12_insert'))
    drop proc D12_insert
go

if (exists (select * from sysobjects where name = 'D12_update'))
    drop proc D12_update
go

if (exists (select * from sysobjects where name = 'D12_delete'))
    drop proc D12_delete
go

if (exists (select * from sysobjects where name = 'M_DELETE_AUTHOR'))
    drop proc M_DELETE_AUTHOR
go

if (exists (select * from sysobjects where name = 'M_UPDATE_AUTHOR'))
    drop proc M_UPDATE_AUTHOR
go

if (exists (select * from sysobjects where name = 'M_INSERT_AUTHOR'))
    drop proc M_INSERT_AUTHOR
go

if (exists (select * from sysobjects where name = 'M_AUTHORS_INFO'))
    drop proc M_AUTHORS_INFO
go

dump tran pubs2 with truncate_only
go


/*-------------------- SECTION III --------------------*/

/*******************************************************/
/************** Create Stored Procedures ***************/
/*******************************************************/


/* Lists the databases for the current server */

print "creating D10_titles"
go

CREATE PROC D10_titles (
	@title varchar(80)
)
AS
	select @title = lower( @title ) + "%"
	SELECT  
		title 
	FROM    
		titles
	WHERE   
		lower(title) like @title
go

grant execute on D10_titles to public
go

dump tran pubs2 with truncate_only
go


print "creating D10_storelist"
go

CREATE PROC D10_storelist
AS
	SELECT 
		stor_name
	FROM
		stores
	ORDER BY
		stor_name
go

grant execute on D10_storelist to public
go

dump tran pubs2 with truncate_only
go


print "creating D10_storesales"
go

CREATE PROC D10_storesales (
	@title varchar(80), @store varchar(40)
)
AS
	SELECT
		"Order #:", d.ord_num, "--",
		"Quanity:", d.qty, "--",
		"Discount:", d.discount
	FROM
		titles t, stores s, salesdetail d
	WHERE
		t.title = @title AND
		t.title_id = d.title_id AND
		s.stor_id = d.stor_id AND
		s.stor_name = @store
go

grant execute on D10_storesales to public
go

dump tran pubs2 with truncate_only
go


print "creating D10_publisher"
go

CREATE PROC D10_publisher (
	@title varchar(80)
)
AS
	SELECT
		p.pub_name,
		p.pub_id,
		p.city,
		p.state
	FROM
		publishers p, titles t
	WHERE
		t.pub_id = p.pub_id AND
		t.title = @title
go

grant execute on D10_publisher to public
go

dump tran pubs2 with truncate_only
go


print "creating D10_author"
go

CREATE PROC D10_author (
	@title varchar(80)
)
AS
	SELECT
		a.au_fname,
		a.au_lname,
		a.address,
		a.city,
		a.state,
		a.postalcode,
		a.phone,
		t.advance,
		t.total_sales
	FROM
		authors a,
		titles t,
		titleauthor ta
	WHERE
		a.au_id = ta.au_id AND
		t.title_id = ta.title_id AND
		t.title = @title
go

grant execute on D10_author to public
go

dump tran pubs2 with truncate_only
go

print "creating D11_info"
go

CREATE PROC D11_info
AS
	SELECT
		au_lname,
		au_fname,
		phone,
		country
	FROM
		authors
	ORDER BY
		au_lname,
		au_fname
go

grant execute on D11_info to public
go

dump tran pubs2 with truncate_only
go


print "creating D12_find"
go

CREATE PROC D12_find
AS
	SELECT  
		pub_id,
		pub_name,
		city,
		state 
	FROM    
		publishers
	ORDER BY
		pub_name
go

grant execute on D12_find to public
go

dump tran pubs2 with truncate_only
go


print "creating D12_insert"
go

CREATE PROC D12_insert (
	@id char(4),
	@name varchar(40),
	@city varchar(20),
	@state char(2)
)
AS
	INSERT
		publishers
	VALUES (
		@id,
		@name,
		@city,
		@state
	)
go

grant execute on D12_insert to public
go

dump tran pubs2 with truncate_only
go


print "creating D12_update"
go

CREATE PROC D12_update (
	@id char(4),
	@name varchar(40),
	@city varchar(20),
	@state char(2)
)
AS
	UPDATE
		publishers
	SET
		pub_name = @name,
		city     = @city,
		state    = @state
	WHERE
		pub_id   = @id
go

grant execute on D12_update to public
go

dump tran pubs2 with truncate_only
go


print "creating D12_delete"
go

CREATE PROC D12_delete (
    @id char(4)
)
AS
	DELETE
	FROM
		publishers
	WHERE
		pub_id = @id
go

grant execute on D12_delete to public
go

dump tran pubs2 with truncate_only
go

print "creating M_AUTHORS_INFO"
go

create procedure M_AUTHORS_INFO
as
select * from authors
go

grant execute on M_AUTHORS_INFO to public
go

dump tran pubs2 with truncate_only
go

print "creating M_INSERT_AUTHOR"
go

create procedure M_INSERT_AUTHOR
(@id id,
@lname varchar(40),
@fname varchar(20),
@phone char(12),
@addr varchar(40),
@city varchar(20),
@state char(2),
@country varchar(12),
@postal char(10))
	as
insert authors
	values(@id,
		@lname,
		@fname,
		@phone,
		@addr,
		@city,
		@state,
		@country,
		@postal)
go

grant execute on M_INSERT_AUTHOR to public
go

dump tran pubs2 with truncate_only
go

print "creating M_UPDATE_AUTHOR"
go

create procedure M_UPDATE_AUTHOR
(@id id,
@lname varchar(40),
@fname varchar(20),
@phone char(12),
@addr varchar(40),
@city varchar(20),
@state char(2),
@country varchar(12),
@postal char(10))
	as
update authors
set au_lname = @lname,
au_fname = @fname,
phone = @phone,
address = @addr,
city = @city,
state = @state,
country = @country,
postalcode = @postal
where au_id = @id
go

grant execute on M_UPDATE_AUTHOR to public
go

dump tran pubs2 with truncate_only
go

print "creating M_DELETE_AUTHOR"
go

create procedure M_DELETE_AUTHOR
(@id id)
	as
delete authors
where au_id = @id
go

grant execute on M_DELETE_AUTHOR to public
go

dump tran pubs2 with truncate_only
go

print "Adding author_url records"
go

insert author_url
values('409-56-7008', '409-56-7008.gif', '409-56-7008.wav')
go
insert author_url
values ('213-46-8915', '213-46-8915.gif', '213-46-8915.wav')
go
insert author_url
values('238-95-7766', '238-95-7766.gif', '238-95-7766.wav')
go
insert author_url
values('998-72-3567', '998-72-3567.gif', '998-72-3567.wav')
go
insert author_url
values('899-46-2035', '899-46-2035.gif', '899-46-2035.wav')
go
insert author_url
values('722-51-5454', '722-51-5454.gif', '722-51-5454.wav')
go
insert author_url
values('807-91-6654', '807-91-6654.gif', '807-91-6654.wav')
go
insert author_url
values('893-72-1158', '893-72-1158.gif', '893-72-1158.wav')
go
insert author_url
values('724-08-9931', '724-08-9931.gif', '724-08-9931.wav')
go
insert author_url
values('274-80-9391', '274-80-9391.gif', '274-80-9391.wav')
go
insert author_url
values('756-30-7391', '756-30-7391.gif', '756-30-7391.wav')
go
insert author_url
values('724-80-9391', '724-80-9391.gif', '724-80-9391.wav')
go
insert author_url
values('427-17-2319', '427-17-2319.gif', '427-17-2319.wav')
go
insert author_url
values('672-71-3249', '672-71-3249.gif', '672-71-3249.wav')
go
insert author_url
values('267-41-2394', '267-41-2394.gif', '267-41-2394.wav')
go
insert author_url
values('472-27-2349', '472-27-2349.gif', '472-27-2349.wav')
go
insert author_url
values('527-72-3246', '527-72-3246.gif', '527-72-3246.wav')
go
insert author_url
values('172-32-1176', '172-32-1176.gif', '172-32-1176.wav')
go
insert author_url
values('712-45-1867', '712-45-1867.gif', '712-45-1867.wav')
go
insert author_url
values('846-92-7186', '846-92-7186.gif', '846-92-7186.wav')
go
insert author_url
values('486-29-1786', '486-29-1786.gif', '486-29-1786.wav')
go
insert author_url
values('648-92-1872', '648-92-1872.gif', '648-92-1872.wav')
go
insert author_url
values('341-22-1782', '341-22-1782.gif', '341-22-1782.wav')
go

if exists (select * from master.dbo.sysdatabases
		where name = "pubs2")
begin
	grant all on author_url to guest
end
go

/*--------------------------- SECTION IV ---------------------------*/

/********************************************************************/
/* This portion returns everything back to normal                   */
/********************************************************************/

use pubs2
go

if exists (select * from sysobjects
           where name = 'sp_configure' and sysstat & 7 = 4)
begin
    execute sp_configure 'update',0
end
reconfigure with override
go
checkpoint
go

