#include "SaApiFunc.h"
#include <stdio.h>

/** ----------------------------------------------------------------------- **/
/** Here are some local procedure definitions that might be useful **/
/**   but are not contained in the API **/
/** ----------------------------------------------------------------------- **/

void Paragraph()
{
  fprintf(stdout, "<P>");
}

void Break()
{
  fprintf(stdout, "<BR>");
}

void HorizRule()
{
  fprintf(stdout, "<HR>");
}

void NewLine()
{
  fprintf(stdout, "\n");
}

/** This call will have an API interface eventually. **/
void ListItemEnd()
{
  fprintf(stdout, "</LI>");
}

/** ----------------------------------------------------------------------- **/
/** Here is the main procedure that is called from Sapphire/Web **/
/** ----------------------------------------------------------------------- **/

void SaApiFunc()
{

  /** Instead of splitting the functionality of formattting the page into **/
  /**   separate procedures, all calls were made directly from this **/
  /**   main procedure. **/

  SaHtmlBegin();

  SaHeadBegin();
  SaHtmlTitle("HTML Page Generated Using API Calls");
  SaHeadEnd();

  SaBodyBegin();

  /** Defined above **/
  HorizRule();

  SaHeader("Some Non-Form Attributes",2);

  /** NewLine calls do not affect the viewable page itself **/
  /** They are inserted to neaten the HTML output that is generated **/
  NewLine();
  SaHeader("Anchors",3);

  /** printf can be used to insert normal text anywhere in the page **/
  fprintf(stdout, "The following external anchor will take you to the ");
  NewLine();
  SaAnchor("http://www.bluestone.com","Bluestone Home Page","bhpage");
  fprintf(stdout, ".");
  Paragraph();
  fprintf(stdout, "The following internal anchor will take you to the ");
  NewLine();
  SaAnchor("#formsection","beginning of the form on this page","bof");
  fprintf(stdout, ".");
  Paragraph();

  NewLine();
  SaHeader("Lists",3);
  NewLine();
  SaUListBegin();
  NewLine();
  SaListHead("This is the header for the following unordered list:");
  NewLine();
  SaListItem("This is a the first list item.");
  NewLine();
  SaListItem("This is a the second list item.");
  NewLine();

  /** Use separate begin/end calls if you want to embed special text/links **/
  /**   inside of a list entry.  **/
  SaListItemBegin();
  fprintf(stdout, "This item has a ");
  NewLine();
  SaAnchor("http://www.bluestone.com","link","bhpage2");
  fprintf(stdout, " to Bluestone's Home Page.");
  ListItemEnd();
  NewLine();
  SaListItem("This is a the fourth list item.");
  NewLine();
  SaUListEnd();

  NewLine();
  SaOListBegin();
  NewLine();
  SaListHead("This is the header for the following ordered list:");
  NewLine();
  SaListItem("This is a the first list item.");
  NewLine();
  SaListItem("This is a the second list item.");
  NewLine();
  SaListItem("This is a the third list item.");
  NewLine();
  SaOListEnd();

  Paragraph();
  fprintf(stdout, "Here is a sample table:");
  Break();
  NewLine();
  SaTableBegin();
  NewLine();
  SaTableRowBegin();
  NewLine();
  SaTableItem("item A");
  NewLine();
  SaTableItem("item B");
  NewLine();

  /** Anchors can also be inserted into Table entries (just like lists) **/
  SaTableItemBegin();
  NewLine();
  SaAnchor("http://www.bluestone.com","link","bhpage2");
  fprintf(stdout, " to Bluestone HP");
  NewLine();
  SaTableRowEnd();
  NewLine();
  SaTableRowBegin();
  NewLine();
  SaTableItem("item D");
  NewLine();
  SaTableItem("item E");
  NewLine();
  SaTableRowEnd();
  NewLine();
  SaTableRowBegin();
  NewLine();
  SaTableItem("item G");
  NewLine();
  SaTableItem("item H");
  NewLine();
  SaTableItem("item I");
  NewLine();
  SaTableRowEnd();
  NewLine();
  SaTableEnd();
  HorizRule();

  NewLine();
  /** NULL defaults to post, see man pages for details on default values **/
  /** "UrlName" is a place holder.  Normally the real URL **/
  /**    of the script to receive the output of the form would go here. **/
  SaFormBegin("UrlName",NULL);

  NewLine();
  SaAnchor(NULL,NULL,"formsection");

  NewLine();
  SaHeader("A Form Example",2); 

  NewLine();
  SaHeader("Text Types",3);
  fprintf(stdout, "Normal Text Box:");
  NewLine();
  SaTextBox("textb1","default",8,10);
  Paragraph();

  /** Multiple printfs are used for code neatness. **/
  /** The line feeds insure that HTML puts a single space between words. **/
  fprintf(stdout, "Here is stored a hidden element containing the original\n");
  fprintf(stdout, "data in the above text field.  This is useful for\n");
  fprintf(stdout, "determining if data was modified on a submit.\n");
  NewLine();
  /** This is an example of how a "shadow" copy of a text field can be **/
  /**   used to see if text was modified by the user **/
  SaFormHidden("textold","default");
  Paragraph();

  fprintf(stdout, "Password:");
  NewLine();
  SaFormPass("pass1",NULL);
  Paragraph();

  fprintf(stdout, "The following is a large text area for the user to/n");
  fprintf(stdout, "type into:");
  Break();
  NewLine();
  SaTextArea("texta","This area is 64 characters across and 4 lines high.",
             4,64,SA_CENTER);
  Paragraph();

  NewLine();
  SaHeader("Radio Buttons and Check Boxes",3);
  fprintf(stdout, "You can set either type up from side to side:");
  Break();
  NewLine();
  /** Spacing in labels makes for readability in page. **/
  SaFormRadio("radio1","rad1",1," one   ");
  NewLine();
  SaFormRadio("radio1","rad2",0," two   ");
  NewLine();
  SaFormRadio("radio1","rad3",0," three");
  Paragraph();

  /** Use Breaks to start next option on next line. **/
  fprintf(stdout, "or from top to bottom:");
  Break();
  NewLine();
  SaFormCheckBox("ch1",NULL,1," Option is pre-checked");
  Break();
  NewLine();
  SaFormCheckBox("ch2",NULL,0," This one is not");
  Break();
  NewLine();
  SaFormCheckBox("ch3",NULL,0," Neither is this one");
  Break();
  NewLine();
  SaFormCheckBox("ch4",NULL,1," But this one is");
  Break();

  NewLine();
  SaHeader("Multiple and Single Select Lists",3);
  NewLine();
  /** Including more options than the list allows for will force a **/
  /**   scrollbar to be used. **/
  SaSelectBegin("mlist",1,3,"Multiple Select Example:");
  NewLine();
  SaSelectOption("m1",0,"Multi Option 1");
  NewLine();
  SaSelectOption("m2",0,"Multi Option 2");
  NewLine();
  SaSelectOption("m3",0,"Multi Option 3");
  NewLine();
  SaSelectOption("m4",0,"Multi Option 4");
  NewLine();
  SaSelectOption("m5",0,"Multi Option 5");
  NewLine();
  SaSelectEnd();
  Paragraph();
  NewLine();
  /** Allowing only 1 entry changes appearance to a pop-up list. **/
  SaSelectBegin("slist",0,1,"Single Select Example:");
  NewLine();
  SaSelectOption("s1",1,"Single Option 1");
  NewLine();
  SaSelectOption("s2",0,"Single Option 2");
  NewLine();
  SaSelectOption("s3",0,"Single Option 3");
  NewLine();
  SaSelectEnd();
  Break();

  NewLine();
  SaHeader("Form Actions",3);
  /** Since the URL specified in the form definition does not exist, **/
  /**   no script will be found, and the user will be told. **/
  fprintf(stdout, "Submitting the form will result in an error since there\n");
  fprintf(stdout, "is no specified place to submit the information to.");
  Break();
  NewLine();
  SaFormSubmit(NULL,"Submit Form");
  NewLine();
  SaFormReset("Clear Form");
  NewLine();
  SaFormEnd();

  NewLine();
  SaBodyEnd();

  NewLine();
  SaHtmlEnd();
}

