#ifndef __WORKINGDIALOG_HEADER__
#define __WORKINGDIALOG_HEADER__

#ifdef _WINDOWS
typedef void XEvent;
typedef void Display;
typedef char* XmString;
typedef void* WidgetClass;
typedef long mode_t;
typedef void* Widget;
typedef void* XtPointer;
#else
#ifdef NOX
#include <sys/types.h>
#ifndef NULL
#define NULL 0
#endif
typedef void* WidgetClass;
typedef void* XtPointer;
#else
#include <sys/types.h>
#include <Xm/Xm.h>
#endif
#endif /* WINDOWS */

#include "SutProto.h"
#include "SutList.h"
#include "SaConsoleCalls.h"
#include "SaDef.h"
#include "SaAddLogin.h"

#ifdef __cplusplus
extern "C" {
#endif

#ifdef WEB
#define UxWidget NULL
#define Widget void*
#define XEvent void
#define Display void
#define XmString void
#endif

#define VULL (void*)0
/**** request modes ***/
#define NO_USE 0
#define USE_IT 1
#define NO_WP 2
#define INTERNAL_USE_ONLY 10100

/*** new object types *****/
#define READ_FILE 1001
#define WRITE_FILE 1002
#define READ_EXEC 1003
#define WRITE_EXEC 1004
#define NULL_EXEC 1005
#define EXEC_FUNCTION 1006
#define COPROCCESS 1007
#define USER_DEFINED 2000

/**** cache usage ****/
#define NO_CACHE 0
#define TO_CACHE 1
#define FROM_CACHE 2

/**** index types ****/
#define ROW_INDEX 0
#define CLEAR_INDEX 1
#define WIDGET_INDEX 2
#define NEXT_INDEX 3
#define PREV_INDEX 4
#define PAGEUP_INDEX 5
#define PAGEDW_INDEX 6
#define HOME_INDEX 7
#define LAST_INDEX 8
#define REFRESH_INDEX 9

/**** queue file flags ****/
#define NO_QUEUE_FILE 0
#define QUEUE_TO_FILE 1

/**** blob flags ****/
#define BLOB_ALL  0
#define BLOB_PART 1
#define BLOB_DONE 2
#define SA_BINARY 0
#define SA_TEXT   1

typedef void (*SaMsgErrHandler) SUTPROTO((int, int, int, char*, int, int));

typedef char* (*SaEncrytpFunc) SUTPROTO((char* value, void* key));

typedef struct {
char ***data;				/* 2D array of string pointers, nRows by nCols */
long nRows;					/* number of rows in this results group */
int nCols;					/* number of columns in this results group */
int *colWidth;				/* actual max col width based on return data */
int *maxColWidth;			/* column width based on database tables */
int *colCodes;				/* hook for future growth */
int *colFormat;				/* hook for future growth */
char **columnTitles;
void *options;				/* hook for future growth */ 
} SaDataStruct;

typedef struct {
int reason;
XEvent *event;
SaDataStruct *groups;		/* array of nGroups SaDataStruct, */
							/*one for each result group */
int nGroups;				/* number of results groups */
} SaCallbackStruct;

/*** Widget, client data, pointer to SaCallbackStruct ***/
typedef void (*PopulationCallback) SUTPROTO((Widget, XtPointer, SaCallbackStruct *));

typedef struct SgeWorkCallData *pSgeWorkCallData;

/****** Function Declarations *****************/

int XKEXPORT SaSetDefaults SUTPROTO((char* server, char* db));
int XKEXPORT SaSetUseDefaultFlag();
int XKEXPORT SaSetDefaultVendor SUTPROTO((int vend));
int XKEXPORT SaSetDefaultUser SUTPROTO((char* user));
int XKEXPORT SaSetDefaultPass SUTPROTO((char* pass));
int XKEXPORT SaGetLabHgt SUTPROTO((Display *display));
int XKEXPORT SaGetButHgt SUTPROTO((Display *display));
int XKEXPORT SaGetButWdt SUTPROTO((Display *display));
int XKEXPORT SaGetTFHgt SUTPROTO((Display *display));
int XKEXPORT SaGetCenterOffset SUTPROTO((Display *display));
void XKEXPORT SaSetMsgErrHandler SUTPROTO((SaMsgErrHandler handler));


typedef int (*SaObjectImpl) SUTPROTO((pSgeWorkCallData));
void XKEXPORT SaRegisterObjImp SUTPROTO((char* name, SaObjectImpl func));

SaCallbackStruct* XKEXPORT SaMakeCbsByCol SUTPROTO((SaCallbackStruct* cbs, int row));

SaCallbackStruct* XKEXPORT SaMakeCbsByGroup SUTPROTO((SaCallbackStruct* cbs, int group));

SaCallbackStruct* XKEXPORT SaMakeCbsStartStopCol SUTPROTO((SaCallbackStruct* cbs,
								int start, int stop));

SaCallbackStruct* XKEXPORT SaMakeCbsColList SUTPROTO((SaCallbackStruct* cbs,
								pSutList colList));

SaCallbackStruct* XKEXPORT SaMakeCbsStartColRange SUTPROTO((SaCallbackStruct* cbs,
								int start, int number));

void XKEXPORT SaFreeCbs SUTPROTO((SaCallbackStruct* cbs));

SaCallbackStruct* XKEXPORT SaExecSQL SUTPROTO((char* serv, char* db,
						int vendor, char* statement));

int XKEXPORT SaGetCancelStatus SUTPROTO(());
int XKEXPORT SaGetErrorStatus SUTPROTO(());
int XKEXPORT SaGetReturnStatus SUTPROTO(());
int XKEXPORT SaGetAffectedRowCount SUTPROTO(());
int XKEXPORT SaGetThisAffectedRowCount SUTPROTO((pSgeWorkCallData p));
int XKEXPORT SaGetThisCancelStatus SUTPROTO((pSgeWorkCallData p));
int XKEXPORT SaGetThisErrorStatus SUTPROTO((pSgeWorkCallData p));
int XKEXPORT SaGetThisReturnStatus SUTPROTO((pSgeWorkCallData p));
int XKEXPORT SaSetTimeOut SUTPROTO((int time_out));
int XKEXPORT SaSetOrbSeed SUTPROTO((int seed));
int XKEXPORT SaSetOrbHost SUTPROTO((char* host));
int XKEXPORT SaSetMaxRows SUTPROTO((int rows));

void XKEXPORT SaResetCancelStatus SUTPROTO(());
void XKEXPORT SaResetErrorStatus SUTPROTO(());
void XKEXPORT SaResetReturnStatus SUTPROTO(());

void XKEXPORT SaSetCancelStatus SUTPROTO(());

void XKEXPORT SgeSetAdHocFlag SUTPROTO((pSgeWorkCallData p));

int XKEXPORT SgePreInitialize SUTPROTO((int *argc, char** argv));

/***** functions for use when a request is a function ******/
int SaReqAppendString SUTPROTO((pSgeWorkCallData p, char* elem));
pSutList SaReqGetOptionList SUTPROTO((pSgeWorkCallData p));
char* SaReqGetArgByName SUTPROTO((pSgeWorkCallData p, char* name));
char* SaReqGetNArg SUTPROTO((pSgeWorkCallData p, int num));
char* SaReqGetNArgName SUTPROTO((pSgeWorkCallData p, int num));
int SaReqGetNumArgs SUTPROTO((pSgeWorkCallData p));
int SaReqSetAffectedRowCount SUTPROTO((pSgeWorkCallData p, int count));
int SaReqSetErrorCode SUTPROTO((pSgeWorkCallData p, int count));
int SaReqSetReturnCode SUTPROTO((pSgeWorkCallData p, int count));
int SaReqAppendError SUTPROTO((pSgeWorkCallData p, int stype, int smajor,
					int sminor, char* msg, int state, int line));
int SaReqSetGroupCount SUTPROTO((pSgeWorkCallData p, int count));
int SaReqAppendRowCount SUTPROTO((pSgeWorkCallData p, int count));
int SaReqAppendColCount SUTPROTO((pSgeWorkCallData p, int count));

pSgeWorkCallData XKEXPORT getSgeWorkCallData SUTPROTO((Widget w, long max,
					char *serv, char *db, char *sproc, int usage));

void XKEXPORT SgeSetCallDetail SUTPROTO((pSgeWorkCallData p, int cache_flag,
					void *cache_key, int index_type, void *index_val,
					void *index_key, int queue_file_flag));

void XKEXPORT SgeSetColBind SUTPROTO((pSgeWorkCallData p, XtPointer dest,
					int group, int order,
					int size, XtPointer cbfunc, XtPointer client));

void XKEXPORT SgeSetColDetail SUTPROTO((pSgeWorkCallData p, int type_id,
					int compute_id, int assoc_col,
					int format_code, char* type_name, char* column_name));

void XKEXPORT DoWorkProc SUTPROTO((pSgeWorkCallData p, int OrbReqType));

void XKEXPORT SgeSetArgBind SUTPROTO((pSgeWorkCallData p,
						int type_id, char* argname, char* argval));

void XKEXPORT SgeSetArgBnd2 SUTPROTO((pSgeWorkCallData p,
						int type_id, int type_size,
						char* argname, char* type_name, char* argval));

void XKEXPORT SgeSetStatement SUTPROTO((pSgeWorkCallData p, char* statement));

void XKEXPORT SgeSetVendor SUTPROTO((pSgeWorkCallData p, int vendor));

void XKEXPORT SgeSetDatabase SUTPROTO((pSgeWorkCallData p, char* database));

void XKEXPORT SgeVaSetFrags SUTPROTO((pSgeWorkCallData p, ...));
int XKEXPORT SaVaSetReqOptions SUTPROTO((pSgeWorkCallData p, ...));
int XKEXPORT SaVaSetCallOptions SUTPROTO((pSgeWorkCallData p, ...));
int XKEXPORT SaVaSetColOptions SUTPROTO((pSgeWorkCallData p, int colNum, ...));
int XKEXPORT SaVaSetArgOptions SUTPROTO((pSgeWorkCallData p, int argNum, ...));
int XKEXPORT SaIsValidReq SUTPROTO((pSgeWorkCallData p));

/*** free a cache given a stored procedure triplet. If the cache id ***/
/*** was not NULL or the triplet doesn't match any cache, nothing happens */
/*** WARNING: valid callback structures may point to a cache. ***/
/*** DO NOT free a cache if any references to a cbs exist ***/
void XKEXPORT SgeDestroyCacheByName SUTPROTO((char* server, char* database,
							char* sproc));

/*** free a cache by its unique id. If the id is not a cache, nothing happens */
/*** WARNING: valid callback structures may point to a cache. ***/
/*** DO NOT free a cache if any references to a cbs exist ***/
void XKEXPORT SgeDestroyCacheById SUTPROTO((void* id));

/**** returns a row number. Only cbs made from cache data will work ***/
/**** any copies of valid cbs will also NOT work ****/
/**** row 0, the first row is returned for any error conditions ***/
int XKEXPORT SgeGetIndexValue SUTPROTO((SaCallbackStruct *cbs, int mode));

/****** Unregisters the client's collection service from the portmapper ****/
/**** and calls exit with the status value. *****/
void XKEXPORT SaExit SUTPROTO((int status));

/****** Unregisters the client's collection service from the portmapper ****/
void XKEXPORT SaUnreg SUTPROTO(());

/****** Reregisters the client's collection service from the portmapper ****/
void XKEXPORT SaRereg SUTPROTO(());

void XKEXPORT SaCatOpen SUTPROTO(());

char* XKEXPORT SaCatGets SUTPROTO((int set_num, int msg_num, char *default_str));

char* XKEXPORT GCat SUTPROTO((int n, int use_malloc));
char* XKEXPORT GCatb SUTPROTO((int n, int use_malloc));

char* XKEXPORT SaGetGeo SUTPROTO((Display *dpy, int which));

void XKEXPORT SaBlobSetLog SUTPROTO((int use_log));

int XKEXPORT SaPutBlob SUTPROTO((
				int vendor,     /* vendor id */
				char *sv,       /* server name */
				char *db,       /* database name */
				char *tab,      /* owner.table name */
				char *col,      /* blob column name */
				int coltype,    /* SGEHEX or SGEASCII */
				char *where,    /* where clause providing unique record */
				int totsize,    /* total size of the blob in bytes */
				void *chunk,    /* the blob data chunk. Can be one piece. */
				int chunksize,  /* the size of the blob data chunk in bytes. */
				int flag ));    /* BLOB_ALL, BLOB_PART, BLOB_DONE */

int XKEXPORT SaPutBlobFromFile SUTPROTO((
				int vendor,     /* vendor id */
				char *sv,       /* server name */
				char *db,       /* database name */
				char *tab,      /* owner.table name */
				char *col,      /* blob column name */
				int coltype,    /* SA_BINARY or SA_TEXT */
				char *where,    /* where clause providing unique record */
				int chunksize,  /* Bytes to transfer in one pass. -1 default */
				char *path ));  /* path and filename to read from */ 

int XKEXPORT SaGetBlob SUTPROTO((
				int vendor,     /* vendor id */
				char *sv,       /* server name */
				char *db,       /* database name */
				char *tab,      /* owner.table name */
				char *col,      /* blob column name */
				int coltype,    /* SA_BINARY or SA_TEXT */
				char *where,    /* where clause providing unique record */
				int chunksize,  /* Bytes to read in one pass. -1 default */
				void **chunk)); /* address of pointer to hold chunk of data */

int XKEXPORT SaGetBlobToFile SUTPROTO((
				int vendor,     /* vendor id */
				char *sv,       /* server name */
				char *db,       /* database name */
				char *tab,      /* owner.table name */
				char *col,      /* blob column name */
				int coltype,    /* SA_BINARY or SA_TEXT */
				char *where,    /* where clause providing unique record */
				int chunksize,  /* Bytes to read in one pass. -1 default */
				char *path,     /* path and filename to write to */
				mode_t mode )); /* permission bits on file. */

void XKEXPORT SaGetBlobDone SUTPROTO((int vendor));

void* XKEXPORT SaAsciiToHex SUTPROTO((char *c, int *siz));
char* XKEXPORT SaHexToAscii SUTPROTO((void *vp, int siz, int prepend));

pSgeWorkCallData XKEXPORT SgeOrbExec SUTPROTO((pSgeWorkCallData cd, int vendor, 
	char *srvname, char *dbname, char *proc, int stype));

#ifdef __cplusplus
}
#endif

#endif
